@@ -9,11 +9,10 @@
 
 """
 
-from pysol_cards.cards import Card, createCards
+from pysol_cards.cards import Card
+from pysol_cards.cards import createCards
 from pysol_cards.random import shuffle
 
-from six import print_
-
 
 def empty_card():
     ret = Card(0, 0, 0)
@@ -102,7 +101,7 @@ class Board(object):
 
     def calc_string(self, renderer):
         self.gen_lines(renderer)
-        return "".join(l + "\n" for l in self._lines)
+        return "".join(line + "\n" for line in self._lines)
 
 
 class Game(object):
@@ -131,6 +130,7 @@ class Game(object):
             "black_hole": [],
             "all_in_a_row": [],
             "golf": [],
+            "binary_star": [],
         }
 
     GAMES_MAP = {}
@@ -148,8 +148,10 @@ class Game(object):
             raise ValueError("Unknown game type " + self.game_id + "\n")
 
     def is_two_decks(self):
-        return self.game_id in ("der_katz", "der_katzenschwantz",
-                                "die_schlange", "gypsy")
+        return self.game_id in (
+            "binary_star", "der_katz", "der_katzenschwantz",
+            "die_schlange", "gypsy"
+        )
 
     def get_num_decks(self):
         return 2 if self.is_two_decks() else 1
@@ -166,7 +168,7 @@ class Game(object):
         return self.board.calc_string(renderer)
 
     def print_layout(self, renderer):
-        print_(self.calc_layout_string(renderer), sep='', end='')
+        print(self.calc_layout_string(renderer), sep='', end='')
 
     def new_cards(self, cards):
         self.cards = cards
@@ -278,20 +280,29 @@ class Game(object):
         if game.game_id == 'streets_and_alleys':
             game.cyclical_deal(4, 4)
 
-    def black_hole(game):
+    def _black_hole_generic(game, num_decks, excludes, f):
         game.board = Board(17)
         game.cards = game._shuffleHookMoveToBottom(
             game.cards,
-            lambda c: (c.id == 13, c.suit),
-            1)
-        next(game)
-        game.cyclical_deal(52 - 1, 17)
-        game.board.raw_foundations_line = 'Foundations: AS'
+            lambda c: (c.id in excludes, c.suit),
+            2)
+        for _ in range(num_decks):
+            next(game)
+        game.cyclical_deal(num_decks * (52 - 1), 17)
+        game.board.raw_foundations_line = 'Foundations: ' + f
+
+    def binary_star(game):
+        return game._black_hole_generic(
+            num_decks=2, excludes=frozenset((13, 38)), f='AS KH')
+
+    def black_hole(game):
+        return game._black_hole_generic(
+            num_decks=1, excludes=frozenset((13, )), f='AS')
 
     def der_katz(game):
         is_ds = game.game_id == 'die_schlange'
         if is_ds:
-            print_('Foundations: H-A S-A D-A C-A H-A S-A D-A C-A')
+            print('Foundations: H-A S-A D-A C-A H-A S-A D-A C-A')
         game.board = Board(9)
         i = 0
         for c in game:
